ipecharts.option.visualmapitems.piecewise module
================================================

.. automodule:: ipecharts.option.visualmapitems.piecewise
   :members:
   :undoc-members:
   :show-inheritance:
